@@ -856,10 +856,12 @@ class ZoneName {
         "Antarctica/McMurdo", "Pacific/Auckland",
         "Antarctica/South_Pole", "Pacific/Auckland",
         "Antarctica/Syowa", "Asia/Riyadh",
-        "Arctic/Longyearbyen", "Europe/Oslo",
+        "Antarctica/Vostok", "Asia/Urumqi",
+        "Arctic/Longyearbyen", "Europe/Berlin",
         "Asia/Aden", "Asia/Riyadh",
         "Asia/Ashkhabad", "Asia/Ashgabat",
         "Asia/Bahrain", "Asia/Qatar",
+        "Asia/Brunei", "Asia/Kuching",
         "Asia/Calcutta", "Asia/Kolkata",
         "Asia/Chongqing", "Asia/Shanghai",
         "Asia/Chungking", "Asia/Shanghai",
@@ -868,6 +870,7 @@ class ZoneName {
         "Asia/Istanbul", "Europe/Istanbul",
         "Asia/Kashgar", "Asia/Urumqi",
         "Asia/Katmandu", "Asia/Kathmandu",
+        "Asia/Kuala_Lumpur", "Asia/Singapore",
         "Asia/Kuwait", "Asia/Riyadh",
         "Asia/Macao", "Asia/Macau",
         "Asia/Muscat", "Asia/Dubai",
@@ -880,7 +883,8 @@ class ZoneName {
         "Asia/Ulan_Bator", "Asia/Ulaanbaatar",
         "Asia/Vientiane", "Asia/Bangkok",
         "Atlantic/Faeroe", "Atlantic/Faroe",
-        "Atlantic/Jan_Mayen", "Europe/Oslo",
+        "Atlantic/Jan_Mayen", "Europe/Berlin",
+        "Atlantic/Reykjavik", "Africa/Abidjan",
         "Atlantic/St_Helena", "Africa/Abidjan",
         "Australia/ACT", "Australia/Sydney",
         "Australia/Canberra", "Australia/Sydney",
@@ -918,19 +922,26 @@ class ZoneName {
         "Etc/UCT", "Etc/UTC",
         "Etc/Universal", "Etc/UTC",
         "Etc/Zulu", "Etc/UTC",
+        "Europe/Amsterdam", "Europe/Brussels",
         "Europe/Belfast", "Europe/London",
         "Europe/Bratislava", "Europe/Prague",
         "Europe/Busingen", "Europe/Zurich",
+        "Europe/Copenhagen", "Europe/Berlin",
         "Europe/Guernsey", "Europe/London",
         "Europe/Isle_of_Man", "Europe/London",
         "Europe/Jersey", "Europe/London",
+        "Europe/Kiev", "Europe/Kyiv",
         "Europe/Ljubljana", "Europe/Belgrade",
+        "Europe/Luxembourg", "Europe/Brussels",
         "Europe/Mariehamn", "Europe/Helsinki",
+        "Europe/Monaco", "Europe/Paris",
         "Europe/Nicosia", "Asia/Nicosia",
+        "Europe/Oslo", "Europe/Berlin",
         "Europe/Podgorica", "Europe/Belgrade",
         "Europe/San_Marino", "Europe/Rome",
         "Europe/Sarajevo", "Europe/Belgrade",
         "Europe/Skopje", "Europe/Belgrade",
+        "Europe/Stockholm", "Europe/Berlin",
         "Europe/Tiraspol", "Europe/Chisinau",
         "Europe/Vaduz", "Europe/Zurich",
         "Europe/Vatican", "Europe/Rome",
@@ -943,10 +954,15 @@ class ZoneName {
         "GMT0", "Etc/GMT",
         "Greenwich", "Etc/GMT",
         "Hongkong", "Asia/Hong_Kong",
-        "Iceland", "Atlantic/Reykjavik",
+        "Iceland", "Africa/Abidjan",
         "Indian/Antananarivo", "Africa/Nairobi",
+        "Indian/Christmas", "Asia/Bangkok",
+        "Indian/Cocos", "Asia/Yangon",
         "Indian/Comoro", "Africa/Nairobi",
+        "Indian/Kerguelen", "Indian/Maldives",
+        "Indian/Mahe", "Asia/Dubai",
         "Indian/Mayotte", "Africa/Nairobi",
+        "Indian/Reunion", "Asia/Dubai",
         "Iran", "Asia/Tehran",
         "Israel", "Asia/Jerusalem",
         "Jamaica", "America/Jamaica",
@@ -963,14 +979,20 @@ class ZoneName {
         "NZ-CHAT", "Pacific/Chatham",
         "Navajo", "America/Denver",
         "PRC", "Asia/Shanghai",
+        "Pacific/Chuuk", "Pacific/Port_Moresby",
         "Pacific/Enderbury", "Pacific/Kanton",
+        "Pacific/Funafuti", "Pacific/Tarawa",
         "Pacific/Johnston", "Pacific/Honolulu",
+        "Pacific/Majuro", "Pacific/Tarawa",
         "Pacific/Midway", "Pacific/Pago_Pago",
-        "Pacific/Ponape", "Pacific/Pohnpei",
+        "Pacific/Pohnpei", "Pacific/Guadalcanal",
+        "Pacific/Ponape", "Pacific/Guadalcanal",
         "Pacific/Saipan", "Pacific/Guam",
         "Pacific/Samoa", "Pacific/Pago_Pago",
-        "Pacific/Truk", "Pacific/Chuuk",
-        "Pacific/Yap", "Pacific/Chuuk",
+        "Pacific/Truk", "Pacific/Port_Moresby",
+        "Pacific/Wake", "Pacific/Tarawa",
+        "Pacific/Wallis", "Pacific/Tarawa",
+        "Pacific/Yap", "Pacific/Port_Moresby",
         "Poland", "Europe/Warsaw",
         "Portugal", "Europe/Lisbon",
         "ROC", "Asia/Taipei",
